@@ -43,7 +43,7 @@ namespace stk {
        - Register State = 1
        - Breath Pressure = 128
 
-    by Perry R. Cook and Gary P. Scavone, 1995 - 2010.
+    by Perry R. Cook and Gary P. Scavone, 1995-2012.
 */
 /***************************************************/
 
@@ -89,6 +89,16 @@ class BlowHole : public Instrmnt
   //! Compute and return one output sample.
   StkFloat tick( unsigned int channel = 0 );
 
+  //! Fill a channel of the StkFrames object with computed outputs.
+  /*!
+    The \c channel argument must be less than the number of
+    channels in the StkFrames argument (the first channel is specified
+    by 0).  However, range checking is only performed if _STK_DEBUG_
+    is defined during compilation, in which case an out-of-range value
+    will trigger an StkError exception.
+  */
+  StkFrames& tick( StkFrames& frames, unsigned int channel = 0 );
+
  protected:
 
   DelayL    delays_[3];
@@ -98,15 +108,14 @@ class BlowHole : public Instrmnt
   PoleZero  vent_;
   Envelope  envelope_;
   Noise     noise_;
-  SineWave vibrato_;
-  unsigned long length_;
+  SineWave  vibrato_;
+
   StkFloat scatter_;
   StkFloat thCoeff_;
   StkFloat rhGain_;
   StkFloat outputGain_;
   StkFloat noiseGain_;
   StkFloat vibratoGain_;
-
 };
 
   inline StkFloat BlowHole :: tick( unsigned int )
@@ -144,6 +153,33 @@ class BlowHole : public Instrmnt
   return lastFrame_[0];
 }
 
+inline StkFrames& BlowHole :: tick( StkFrames& frames, unsigned int channel )
+{
+  unsigned int nChannels = lastFrame_.channels();
+#if defined(_STK_DEBUG_)
+  if ( channel > frames.channels() - nChannels ) {
+    oStream_ << "BlowHole::tick(): channel and StkFrames arguments are incompatible!";
+    handleError( StkError::FUNCTION_ARGUMENT );
+  }
+#endif
+
+  StkFloat *samples = &frames[channel];
+  unsigned int j, hop = frames.channels() - nChannels;
+  if ( nChannels == 1 ) {
+    for ( unsigned int i=0; i<frames.frames(); i++, samples += hop )
+      *samples++ = tick();
+  }
+  else {
+    for ( unsigned int i=0; i<frames.frames(); i++, samples += hop ) {
+      *samples++ = tick();
+      for ( j=1; j<nChannels; j++ )
+        *samples++ = lastFrame_[j];
+    }
+  }
+
+  return frames;
+}
+
 } // stk namespace
 
 #endif
