@@ -28,9 +28,12 @@ namespace stk {
        - Bow Position = 4
        - Vibrato Frequency = 11
        - Vibrato Gain = 1
+       - Bow Velocity = 100
+       - Frequency = 101
        - Volume = 128
 
-    by Perry R. Cook and Gary P. Scavone, 1995 - 2010.
+    by Perry R. Cook and Gary P. Scavone, 1995-2012.
+    Contributions by Esteban Maestre, 2011.
 */
 /***************************************************/
 
@@ -38,7 +41,7 @@ class Bowed : public Instrmnt
 {
  public:
   //! Class constructor, taking the lowest desired playing frequency.
-  Bowed( StkFloat lowestFrequency );
+  Bowed( StkFloat lowestFrequency = 8.0 );
 
   //! Class destructor.
   ~Bowed( void );
@@ -50,7 +53,7 @@ class Bowed : public Instrmnt
   void setFrequency( StkFloat frequency );
 
   //! Set vibrato gain.
-  void setVibrato( StkFloat gain );
+  void setVibrato( StkFloat gain ) { vibratoGain_ = gain; };
 
   //! Apply breath pressure to instrument with given amplitude and rate of increase.
   void startBowing( StkFloat amplitude, StkFloat rate );
@@ -70,15 +73,27 @@ class Bowed : public Instrmnt
   //! Compute and return one output sample.
   StkFloat tick( unsigned int channel = 0 );
 
+  //! Fill a channel of the StkFrames object with computed outputs.
+  /*!
+    The \c channel argument must be less than the number of
+    channels in the StkFrames argument (the first channel is specified
+    by 0).  However, range checking is only performed if _STK_DEBUG_
+    is defined during compilation, in which case an out-of-range value
+    will trigger an StkError exception.
+  */
+  StkFrames& tick( StkFrames& frames, unsigned int channel = 0 );
+
  protected:
 
   DelayL   neckDelay_;
   DelayL   bridgeDelay_;
   BowTable bowTable_;
   OnePole  stringFilter_;
-  BiQuad   bodyFilter_;
+  BiQuad   bodyFilters_[6];
   SineWave vibrato_;
   ADSR     adsr_;
+
+  bool     bowDown_;
   StkFloat maxVelocity_;
   StkFloat baseDelay_;
   StkFloat vibratoGain_;
@@ -89,24 +104,54 @@ class Bowed : public Instrmnt
 inline StkFloat Bowed :: tick( unsigned int )
 {
   StkFloat bowVelocity = maxVelocity_ * adsr_.tick();
-  StkFloat bridgeRefl = -stringFilter_.tick( bridgeDelay_.lastOut() );
-  StkFloat nutRefl = -neckDelay_.lastOut();
-  StkFloat stringVel = bridgeRefl + nutRefl;               // Sum is string velocity
-  StkFloat velDiff = bowVelocity - stringVel;              // Differential velocity
-  StkFloat newVel = velDiff * bowTable_.tick( velDiff );   // Non-Linear bow function
-  neckDelay_.tick(bridgeRefl + newVel);                    // Do string propagations
-  bridgeDelay_.tick(nutRefl + newVel);
+  StkFloat bridgeReflection = -stringFilter_.tick( bridgeDelay_.lastOut() );
+  StkFloat nutReflection = -neckDelay_.lastOut();
+  StkFloat stringVelocity = bridgeReflection + nutReflection;
+  StkFloat deltaV = bowVelocity - stringVelocity;             // Differential velocity
+
+  StkFloat newVelocity = 0.0;
+  if ( bowDown_ )
+    newVelocity = deltaV * bowTable_.tick( deltaV );     // Non-Linear bow function
+  neckDelay_.tick( bridgeReflection + newVelocity);      // Do string propagations
+  bridgeDelay_.tick(nutReflection + newVelocity);
     
   if ( vibratoGain_ > 0.0 )  {
     neckDelay_.setDelay( (baseDelay_ * (1.0 - betaRatio_) ) + 
                          (baseDelay_ * vibratoGain_ * vibrato_.tick()) );
   }
 
-  lastFrame_[0] = bodyFilter_.tick( bridgeDelay_.lastOut() );
+  lastFrame_[0] = 0.1248 * bodyFilters_[5].tick( bodyFilters_[4].tick( bodyFilters_[3].tick( bodyFilters_[2].tick( bodyFilters_[1].tick( bodyFilters_[0].tick( bridgeDelay_.lastOut() ) ) ) ) ) );
 
   return lastFrame_[0];
 }
 
+inline StkFrames& Bowed :: tick( StkFrames& frames, unsigned int channel )
+{
+  unsigned int nChannels = lastFrame_.channels();
+#if defined(_STK_DEBUG_)
+  if ( channel > frames.channels() - nChannels ) {
+    oStream_ << "Bowed::tick(): channel and StkFrames arguments are incompatible!";
+    handleError( StkError::FUNCTION_ARGUMENT );
+  }
+#endif
+
+  StkFloat *samples = &frames[channel];
+  unsigned int j, hop = frames.channels() - nChannels;
+  if ( nChannels == 1 ) {
+    for ( unsigned int i=0; i<frames.frames(); i++, samples += hop )
+      *samples++ = tick();
+  }
+  else {
+    for ( unsigned int i=0; i<frames.frames(); i++, samples += hop ) {
+      *samples++ = tick();
+      for ( j=1; j<nChannels; j++ )
+        *samples++ = lastFrame_[j];
+    }
+  }
+
+  return frames;
+}
+
 } // stk namespace
 
 #endif
