@@ -2,6 +2,7 @@
 #define STK_NOISE_H
 
 #include "Generator.h"
+#include <stdlib.h>
 
 namespace stk {
 
@@ -13,7 +14,7 @@ namespace stk {
     C rand() function.  The quality of the rand()
     function varies from one OS to another.
 
-    by Perry R. Cook and Gary P. Scavone, 1995 - 2010.
+    by Perry R. Cook and Gary P. Scavone, 1995-2012.
 */
 /***************************************************/
 
@@ -64,7 +65,7 @@ inline StkFrames& Noise :: tick( StkFrames& frames, unsigned int channel )
 {
 #if defined(_STK_DEBUG_)
   if ( channel >= frames.channels() ) {
-    errorString_ << "Noise::tick(): channel and StkFrames arguments are incompatible!";
+    oStream_ << "Noise::tick(): channel and StkFrames arguments are incompatible!";
     handleError( StkError::FUNCTION_ARGUMENT );
   }
 #endif
