@@ -9,8 +9,6 @@ set cont4 64.0
 set cont7 128.0
 set cont11 64.0
 set cont44 24.0
-set outID "stdout"
-set commtype "stdout"
 set oldpatch 0
 set patchnum 0
 
@@ -19,17 +17,6 @@ wm title . "STK Physical Model Controller"
 wm iconname . "physical"
 . config -bg black
 
-# Configure "communications" menu
-menu .menu -tearoff 0
-menu .menu.communication -tearoff 0 
-.menu add cascade -label "Communication" -menu .menu.communication \
-    -underline 0
-.menu.communication add radio -label "Console" -variable commtype \
-    -value "stdout" -command { setComm }
-.menu.communication add radio -label "Socket" -variable commtype \
-    -value "socket" -command { setComm }
-. configure -menu .menu
-
 # Configure patch change buttons
 frame .radios1 -bg black
 frame .radios2 -bg black
@@ -68,7 +55,6 @@ pack .radios2.pluk -side left -padx 5 -pady 10
 pack .radios2.karp -side left -padx 5 -pady 10
 pack .radios2.sitr -side left -padx 5 -pady 10
 pack .radios2.mand -side left -padx 5 -pady 10
-pack .radios2.blot -side left -padx 5 -pady 10
 
 pack .radios1
 pack .radios2
@@ -100,50 +86,50 @@ frame .left -bg black
 frame .right -bg black
 
 scale .left.volume -from 0 -to 128 -length 200 \
--command {printWhatz "ControlChange    0.0  1 " 7} \
--orient horizontal -label "Volume" \
--tickinterval 32 -showvalue true -bg grey66  \
--variable cont7
+    -command {printWhatz "ControlChange    0.0  1 " 7} \
+    -orient horizontal -label "Volume" \
+    -tickinterval 32 -showvalue true -bg grey66  \
+    -variable cont7
 
 scale .left.bPressure -from 0 -to 128 -length 200 \
--command {changePress } -variable press \
--orient horizontal -label "Breath Pressure" \
--tickinterval 32 -showvalue true -bg grey66
+    -command {changePress } -variable press \
+    -orient horizontal -label "Breath Pressure" \
+    -tickinterval 32 -showvalue true -bg grey66
 
 scale .left.pitch -from 0 -to 128 -length 200 \
--command {changePitch } -variable pitch \
--orient horizontal -label "MIDI Note Number" \
--tickinterval 32 -showvalue true -bg grey66
+    -command {changePitch } -variable pitch \
+    -orient horizontal -label "MIDI Note Number" \
+    -tickinterval 32 -showvalue true -bg grey66
 
 scale .left.cont2 -from 0 -to 128 -length 200 \
--command {printWhatz "ControlChange    0.0 1 " 2} \
--orient horizontal -label "Reed Stiffness" \
--tickinterval 32 -showvalue true -bg grey66  \
--variable cont2
+    -command {printWhatz "ControlChange    0.0 1 " 2} \
+    -orient horizontal -label "Reed Stiffness" \
+    -tickinterval 32 -showvalue true -bg grey66  \
+    -variable cont2
 
 scale .right.reverb -from 0 -to 128 -length 200 \
--command {printWhatz "ControlChange    0.0  1 " 44} \
--orient horizontal -label "Reverb Mix" \
--tickinterval 32 -showvalue true -bg grey66  \
--variable cont44
+    -command {printWhatz "ControlChange    0.0  1 " 44} \
+    -orient horizontal -label "Reverb Mix" \
+    -tickinterval 32 -showvalue true -bg grey66  \
+    -variable cont44
 
 scale .right.cont4 -from 0 -to 128 -length 200 \
--command {printWhatz "ControlChange    0.0 1 " 4} \
--orient horizontal -label "Breath Noise" \
--tickinterval 32 -showvalue true -bg grey66  \
--variable cont4
+    -command {printWhatz "ControlChange    0.0 1 " 4} \
+    -orient horizontal -label "Breath Noise" \
+    -tickinterval 32 -showvalue true -bg grey66  \
+    -variable cont4
 
 scale .right.cont11 -from 0 -to 128 -length 200 \
--command {printWhatz "ControlChange    0.0 1 " 11} \
--orient horizontal -label "Vibrato Rate" \
--tickinterval 32 -showvalue true -bg grey66  \
--variable cont11 
+    -command {printWhatz "ControlChange    0.0 1 " 11} \
+    -orient horizontal -label "Vibrato Rate" \
+    -tickinterval 32 -showvalue true -bg grey66  \
+    -variable cont11 
 
 scale .right.cont1 -from 0 -to 128 -length 200 \
--command {printWhatz "ControlChange    0.0 1 " 1} \
--orient horizontal -label "Vibrato Amount" \
--tickinterval 32 -showvalue true -bg grey66  \
--variable cont1
+    -command {printWhatz "ControlChange    0.0 1 " 1} \
+    -orient horizontal -label "Vibrato Amount" \
+    -tickinterval 32 -showvalue true -bg grey66  \
+    -variable cont1
 
 pack .left.volume -padx 10 -pady 10
 pack .left.bPressure -padx 10 -pady 10
@@ -157,37 +143,32 @@ pack .right.cont1 -padx 10 -pady 10
 pack .left -side left
 pack .right -side right
 
-#bind all <KeyPress> {
-bind . <KeyPress> {
-    noteOn $pitch $press 
-}
+bind . <KeyPress> { noteOn $pitch $press }
 
 # Bind an X windows "close" event with the Exit routine
 bind . <Destroy> +myExit
 
 proc myExit {} {
-    global pitch outID
-    puts $outID [format "ExitProgram"]
-    flush $outID
-    close $outID
+    global pitch
+    puts [format "ExitProgram"]
+    flush stdout
+    close stdout
     exit
 }
 
 proc noteOn {pitchVal pressVal} {
-    global outID
-    puts $outID [format "NoteOn           0.0 1 %f %f" $pitchVal $pressVal]
-    flush $outID
+    puts [format "NoteOn           0.0 1 %f %f" $pitchVal $pressVal]
+    flush stdout
 }
 
 proc noteOff {pitchVal pressVal} {
-    global outID
-    puts $outID [format "NoteOff          0.0 1 %f %f" $pitchVal $pressVal]
-    flush $outID
+    puts [format "NoteOff          0.0 1 %f %f" $pitchVal $pressVal]
+    flush stdout
 }
 
 proc patchChange {value} {
-    global outID bitmappath cont1 cont2 cont4 cont11 pitch oldpatch
-    puts $outID [format "ProgramChange    0.0 1 %i" $value]
+    global bitmappath cont1 cont2 cont4 cont11 pitch oldpatch
+    puts [format "ProgramChange    0.0 1 %i" $value]
         if {$value==0}	{ # Clarinet
             .pretty config -bitmap @$bitmappath/Klar.xbm
             .left.bPressure config -state normal -label "Breath Pressure"
@@ -273,7 +254,7 @@ proc patchChange {value} {
             printWhatz "ControlChange    0.0  1 " 2  $cont2
             printWhatz "ControlChange    0.0  1 " 4  $cont4
             printWhatz "ControlChange    0.0  1 " 11 $cont11
-            puts $outID [format "NoteOn           0.0  1  %3.2f  %3.2f" $pitch $press]
+            puts [format "NoteOn           0.0  1  %3.2f  %3.2f" $pitch $press]
         }
         if {$value==5}	{ # Bottle
             .pretty config -bitmap @$bitmappath/prcFunny.xbm
@@ -300,7 +281,7 @@ proc patchChange {value} {
             .right.cont1 config -state normal -label "Vibrato Amount"
             set cont1 4.0
             set cont2 64.0
-            set cont4 64.0
+            set cont4 24.0
             set cont11 64.0
             printWhatz "ControlChange    0.0  1 " 1  $cont1
             printWhatz "ControlChange    0.0  1 " 2  $cont2
@@ -363,87 +344,49 @@ proc patchChange {value} {
 }
 
 proc printWhatz {tag value1 value2 } {
-    global outID
-    puts $outID [format "%s %i %f" $tag $value1 $value2]
-    flush $outID
+    puts [format "%s %i %f" $tag $value1 $value2]
+    flush stdout
 }
 
 proc changePress {value} {
-    global outID patchnum
+    global patchnum
     if { $patchnum<7 || $patchnum>9 } {
-      puts $outID [format "AfterTouch       0.0 1 %f" $value]
-      flush $outID
+      puts [format "AfterTouch       0.0 1 %f" $value]
+      flush stdout
     }
 }
 
 proc changePitch {value} {
-    global outID
-    puts $outID [format "PitchChange      0.0 1 %.3f" $value]
-    flush $outID
+    puts [format "PitchChange      0.0 1 %.3f" $value]
+    flush stdout
 }
 
-# Socket connection procedure
-set d .socketdialog
+bind . <Configure> { center_the_toplevel %W }
+proc center_the_toplevel { w } {
 
-proc setComm {} {
-		global outID
-		global commtype
-		global d
-		if {$commtype == "stdout"} {
-				if { [string compare "stdout" $outID] } {
-						set i [tk_dialog .dialog "Break Socket Connection?" {You are about to break an existing socket connection ... is this what you want to do?} "" 0 Cancel OK]
-						switch $i {
-								0 {set commtype "socket"}
-								1 {close $outID
-								   set outID "stdout"}
-						}
-				}
-		} elseif { ![string compare "stdout" $outID] } {
-				set sockport 2001
-        set sockhost localhost
-				toplevel $d
-				wm title $d "STK Client Socket Connection"
-				wm resizable $d 0 0
-				grab $d
-				label $d.message -text "Specify a socket host and port number below (if different than the STK defaults shown) and then click the \"Connect\" button to invoke a socket-client connection attempt to the STK socket server." \
-								-background white -font {Helvetica 10 bold} \
-								-wraplength 3i -justify left
-				frame $d.sockhost
-				entry $d.sockhost.entry -width 15
-				label $d.sockhost.text -text "Socket Host:" \
-								-font {Helvetica 10 bold}
-				frame $d.sockport
-				entry $d.sockport.entry -width 15
-				label $d.sockport.text -text "Socket Port:" \
-								-font {Helvetica 10 bold}
-				pack $d.message -side top -padx 5 -pady 10
-				pack $d.sockhost.text -side left -padx 1 -pady 2
-				pack $d.sockhost.entry -side right -padx 5 -pady 2
-				pack $d.sockhost -side top -padx 5 -pady 2
-				pack $d.sockport.text -side left -padx 1 -pady 2
-				pack $d.sockport.entry -side right -padx 5 -pady 2
-				pack $d.sockport -side top -padx 5 -pady 2
-				$d.sockhost.entry insert 0 $sockhost
-				$d.sockport.entry insert 0 $sockport
-				frame $d.buttons
-				button $d.buttons.cancel -text "Cancel" -bg grey66 \
-								-command { set commtype "stdout"
-				                   set outID "stdout"
-				                   destroy $d }
-				button $d.buttons.connect -text "Connect" -bg grey66 \
-								-command {
-						set sockhost [$d.sockhost.entry get]
-						set sockport [$d.sockport.entry get]
-					  set err [catch {socket $sockhost $sockport} outID]
+    # Callback on the <Configure> event for a toplevel
+    # that should be centered on the screen
 
-						if {$err == 0} {
-								destroy $d
-						} else {
-								tk_dialog $d.error "Socket Error" {Error: Unable to make socket connection.  Make sure the STK socket server is first running and that the port number is correct.} "" 0 OK 
-				}   }
-				pack $d.buttons.cancel -side left -padx 5 -pady 10
-				pack $d.buttons.connect -side right -padx 5 -pady 10
-				pack $d.buttons -side bottom -padx 5 -pady 10
-		}
-}
+    # Make sure that we aren't configuring a child window
+    if { [string equal $w [winfo toplevel $w]] } {
 
+        # Calculate the desired geometry
+        set width [winfo reqwidth $w]
+        set height [winfo reqheight $w]
+        set x [expr { ( [winfo vrootwidth  $w] - $width  ) / 2 }]
+        set y [expr { ( [winfo vrootheight $w] - $height ) / 2 }]
+        #set y 0
+
+        # Hand the geometry off to the window manager
+        wm geometry $w ${width}x${height}+${x}+${y}
+
+        # Unbind <Configure> so that this procedure is
+        # not called again when the window manager finishes
+        # centering the window.  Also, revert geometry management
+        # to internal default for subsequent size changes.
+        bind $w <Configure> {}
+        wm geometry $w ""
+    }
+
+    return
+}
\ No newline at end of file
