@@ -10,7 +10,7 @@
     A non-interpolating delay line is typically used in fixed
     delay-length applications, such as for reverberation.
 
-    by Perry R. Cook and Gary P. Scavone, 1995-2011.
+    by Perry R. Cook and Gary P. Scavone, 1995-2012.
 */
 /***************************************************/
 
@@ -69,7 +69,7 @@ void TapDelay :: setTapDelays( std::vector<unsigned long> taps )
     }
 
     if ( taps[i] < 0 ) {
-      error << "TapDelay::setDelay: argument (" << taps[i] << ") less than zero!\n";
+      oStream_ << "TapDelay::setDelay: argument (" << taps[i] << ") less than zero!\n";
       handleError( StkError::WARNING ); return;
     }
   }
